/**
 * @file
 * Provides some very basic filtering functionality for @axe-core/cli results.
 */

(function ($, Drupal, drupalSettings) {
  'use strict';

  Drupal.accessibilityScanner = Drupal.accessibilityScanner || {};
  Drupal.accessibilityScanner.axeCoreCli = {
    drawCharts: function () {
      Drupal.accessibilityScanner.axeCoreCli.drawPreviewChart();
    },
    drawPreviewChart: function () {
      var colorPalette = ['#bb1818', '#f46d12', '#e7b416', '#1c6e8c', '#a8a8a8', '#2dc937'];
      var charts = document.getElementsByClassName('axecore-cli-summary__chart');
      for (var i = 0; i < charts.length; i++) {
        var chart = charts[i];
        var total = +chart.dataset.violations + +chart.dataset.passes + +chart.dataset.incomplete;
        var data = [
          [Drupal.t('Type'), Drupal.t('Quantity')],
          [Drupal.t('Violations (Critical)'), +chart.dataset.violationsCritical],
          [Drupal.t('Violations (Serious)'), +chart.dataset.violationsSerious],
          [Drupal.t('Violations (Moderate)'), +chart.dataset.violationsModerate],
          [Drupal.t('Violations (Minor)'), +chart.dataset.violationsMinor],
          [Drupal.t('Needs Review'), +chart.dataset.incomplete],
          [Drupal.t('Passing'), +chart.dataset.passes],
        ];

        var dataTable = google.visualization.arrayToDataTable(data);
        var chart = new google.visualization.PieChart(chart);
        var options = {
          annotations: {
            alwaysOutside: true,
            textStyle: {
              fontSize: 16,
              auraColor: 'none',
              color: '#555'
            },
          },
          chart: {
            title: '',
            subtitle: '',
          },
          chartArea:{left:0,top:0,bottom:0,top:0, width: '100%'},
          colors: colorPalette,
        };

        chart.draw(dataTable, options);
      }
    }

  }

  Drupal.behaviors.accessibilityScannerAxeCoreCliGoogleChart = {
    attach: function attach(context) {
      google.charts.load('current', {packages: ['corechart', 'bar']});
      google.charts.setOnLoadCallback(Drupal.accessibilityScanner.axeCoreCli.drawCharts);
    }
  };

})(jQuery, Drupal, drupalSettings);
